==> kubernetes-model-1.0.50-sources.jar: annotations/io/fabric8/openshift/api/model/CustomBuildStrategyBuilder.java <==
package io.fabric8.openshift.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.List;
import java.util.ArrayList;
import java.util.RandomAccess;
import java.util.Map;
import java.util.Map;
import java.util.List;
import java.util.AbstractCollection;
import java.util.List;
import java.util.AbstractList;
import java.util.HashMap;
import java.io.Serializable;
import java.util.Collection;
import io.fabric8.kubernetes.api.model.LocalObjectReference;
import java.util.AbstractMap;
import io.fabric8.kubernetes.api.model.EnvVar;
import io.fabric8.kubernetes.api.model.ObjectReference;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Visitable;

public class CustomBuildStrategyBuilder extends CustomBuildStrategyFluentImpl<CustomBuildStrategyBuilder> implements VisitableBuilder<CustomBuildStrategy,CustomBuildStrategyBuilder>{

     CustomBuildStrategyFluent<?> fluent;
public CustomBuildStrategyBuilder(){
    this(new CustomBuildStrategy());
}
public CustomBuildStrategyBuilder( CustomBuildStrategyFluent<?> fluent ){
    this(fluent, new CustomBuildStrategy());
}
public CustomBuildStrategyBuilder( CustomBuildStrategyFluent<?> fluent , CustomBuildStrategy instance ){
    this.fluent = fluent; fluent.withBuildAPIVersion(instance.getBuildAPIVersion()); fluent.withEnv(instance.getEnv()); fluent.withExposeDockerSocket(instance.getExposeDockerSocket()); fluent.withForcePull(instance.getForcePull()); fluent.withFrom(instance.getFrom()); fluent.withPullSecret(instance.getPullSecret()); fluent.withSecrets(instance.getSecrets()); 
}
public CustomBuildStrategyBuilder( CustomBuildStrategy instance ){
    this.fluent = this; this.withBuildAPIVersion(instance.getBuildAPIVersion()); this.withEnv(instance.getEnv()); this.withExposeDockerSocket(instance.getExposeDockerSocket()); this.withForcePull(instance.getForcePull()); this.withFrom(instance.getFrom()); this.withPullSecret(instance.getPullSecret()); this.withSecrets(instance.getSecrets()); 
}

public CustomBuildStrategy build(){
    CustomBuildStrategy buildable = new CustomBuildStrategy(fluent.getBuildAPIVersion(),fluent.getEnv(),fluent.isExposeDockerSocket(),fluent.isForcePull(),fluent.getFrom(),fluent.getPullSecret(),fluent.getSecrets());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
CustomBuildStrategyBuilder that = (CustomBuildStrategyBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    Validator validator = null;
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        validator = factory.getValidator();
    } catch(ValidationException e) {
        //ignore
        return;
    }

    Set<ConstraintViolation<T>> violations = validator.validate(item);
    if (!violations.isEmpty()) {
        throw new ConstraintViolationException(violations);
    }
}

}

==> kubernetes-model-1.0.51-sources.jar: annotations/io/fabric8/openshift/api/model/CustomBuildStrategyBuilder.java <==
package io.fabric8.openshift.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.List;
import java.util.ArrayList;
import java.util.RandomAccess;
import java.util.Map;
import io.fabric8.kubernetes.api.model.KubernetesResource;
import java.util.Map;
import java.util.List;
import java.util.AbstractCollection;
import java.util.List;
import java.util.AbstractList;
import java.util.HashMap;
import java.io.Serializable;
import java.util.Collection;
import io.fabric8.kubernetes.api.model.LocalObjectReference;
import java.util.AbstractMap;
import io.fabric8.kubernetes.api.model.EnvVar;
import io.fabric8.kubernetes.api.model.ObjectReference;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.BaseFluent;

public class CustomBuildStrategyBuilder extends CustomBuildStrategyFluentImpl<CustomBuildStrategyBuilder> implements VisitableBuilder<CustomBuildStrategy,CustomBuildStrategyBuilder>{

     CustomBuildStrategyFluent<?> fluent;
public CustomBuildStrategyBuilder(){
    this(new CustomBuildStrategy());
}
public CustomBuildStrategyBuilder( CustomBuildStrategyFluent<?> fluent ){
    this(fluent, new CustomBuildStrategy());
}
public CustomBuildStrategyBuilder( CustomBuildStrategyFluent<?> fluent , CustomBuildStrategy instance ){
    this.fluent = fluent; fluent.withBuildAPIVersion(instance.getBuildAPIVersion()); fluent.withEnv(instance.getEnv()); fluent.withExposeDockerSocket(instance.getExposeDockerSocket()); fluent.withForcePull(instance.getForcePull()); fluent.withFrom(instance.getFrom()); fluent.withPullSecret(instance.getPullSecret()); fluent.withSecrets(instance.getSecrets()); 
}
public CustomBuildStrategyBuilder( CustomBuildStrategy instance ){
    this.fluent = this; this.withBuildAPIVersion(instance.getBuildAPIVersion()); this.withEnv(instance.getEnv()); this.withExposeDockerSocket(instance.getExposeDockerSocket()); this.withForcePull(instance.getForcePull()); this.withFrom(instance.getFrom()); this.withPullSecret(instance.getPullSecret()); this.withSecrets(instance.getSecrets()); 
}

public CustomBuildStrategy build(){
    CustomBuildStrategy buildable = new CustomBuildStrategy(fluent.getBuildAPIVersion(),fluent.getEnv(),fluent.isExposeDockerSocket(),fluent.isForcePull(),fluent.getFrom(),fluent.getPullSecret(),fluent.getSecrets());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
CustomBuildStrategyBuilder that = (CustomBuildStrategyBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}
